/* ESI AIS Parser
 * 
 * Copyright 2011/2012 by Pierre van de Laar & Pierre America (Embedded Systems Institute)
 * Copyright 2008 by Brian C. Lane <bcl@brianlane.com>
 * All Rights Reserved
 * 
 */
package nl.esi.metis.aisparser.annotations;


/** This class represents annotations related to illegal latitude values according to the AIS standard that are detected during parsing of AIS messages.
 * These annotations are stored in the provenance of the resulting message objects, so that they can analyzed by a client program.
 * @author Pierre van de Laar
 */
public class AISIllegalLatitudeAnnotation implements AISAnnotation {
	private double latitude;
	private String parameterName;
	
	/** Constructor. 
	 * @param latitude received, illegal latitude value 
	 */
	public AISIllegalLatitudeAnnotation(double latitude)
	{
		this.latitude = latitude;
		this.parameterName = "latitude";
	}

	/** Constructor. 
	 * @param parameterName Name of the latitude parameter whose value is illegal.
	 * @param latitude received, illegal latitude value 
	 */
	public AISIllegalLatitudeAnnotation(String parameterName, double latitude)
	{
		this.latitude = latitude;
		this.parameterName = parameterName;
	}

	public String toString()
	{
		return "Violation of standard: " + parameterName + " has latitude value of " + latitude + " outside range [-90,90] and not 91"; 
	}
}
