/* ESI AIS Parser
 * 
 * Copyright 2011/2012 by Pierre van de Laar & Pierre America (Embedded Systems Institute)
 * Copyright 2008 by Brian C. Lane <bcl@brianlane.com>
 * All Rights Reserved
 * 
 */
package nl.esi.metis.aisparser.annotations;


/** This class represents annotations related to illegal longitude values according to the AIS standard that are detected during parsing of AIS messages.
 * These annotations are stored in the provenance of the resulting message objects, so that they can analyzed by a client program.
 * @author Pierre van de Laar
 */
public class AISIllegalLongitudeAnnotation implements AISAnnotation {
	private double longitude;
	private String parameterName;
	
	/** Constructor. 
	 * @param longitude received, illegal longitude value 
	 */
	public AISIllegalLongitudeAnnotation(double longitude)
	{
		this.longitude = longitude;
		this.parameterName = "longitude";
	}

	/** Constructor. 
	 * @param parameterName Name of the longitude parameter whose value is illegal.
	 * @param longitude received, illegal longitude value 
	 */
	public AISIllegalLongitudeAnnotation(String parameterName, double longitude)
	{
		this.longitude = longitude;
		this.parameterName = parameterName;
	}

	public String toString()
	{
		return "Violation of standard: " + parameterName + " has longitude value of " + longitude + " outside range [-180,180] and not 181"; 
	}
}