/* ESI AIS Parser
 * 
 * Copyright 2011/2012 by Pierre van de Laar & Pierre America (Embedded Systems Institute)
 * Copyright 2008 by Brian C. Lane <bcl@brianlane.com>
 * All Rights Reserved
 * 
 */
package nl.esi.metis.aisparser.annotations;


/** This class represents annotations related to deviations from the AIS standard that are detected during parsing of AIS messages.
 * These annotations are stored in the provenance of the resulting message objects, so that they can analyzed by a client program.
 * @author Pierre America
 * @author Pierre van de Laar
 */
public class AISSpareNonZeroAnnotation implements AISAnnotation {
	private int id = 0;
	
	/** Constructor for AISMessage with one spare field. */
	public AISSpareNonZeroAnnotation()
	{
		
	}
	/** Constructor for AISMessage with multiple spare fields. 
	 * @param id identifier of spare field (from 1 to N)
	 */
	public AISSpareNonZeroAnnotation(int id)
	{
		this.id = id;
	}
	
	public String toString()
	{
		StringBuilder sb = new StringBuilder("Violation of standard: Spare ");
		if (id > 0)
		{
			sb.append(id + " ");
		}
		sb.append("Non Zero");
		return sb.toString(); 
	}
}
